Allen Data Information

### Special Datasets
It seems Allen Brain has several ISH Gene Expression datasets with a high number of slices.
Those volumes can be found: http://connectivity.brain-map.org/static/referencedata.
The download of the three Immunohistochemistry volumes has been included to the DVC pipeline.
Opening each experiment link gives you access to some metadata information
including the experiment ID (which that has been used to download those data).
The dataset IDs are 100142290, 100142355 and 100141805.


### ISH Gene Expression Datasets
